@@ -21,6 +21,8 @@
  * IN THE SOFTWARE.
  */
 
+#include <config.h>
+
 #include <stdint.h>
 #include <string.h>  // for memcpy, size_t, strcmp
 
@@ -31,8 +33,16 @@
 #include <girepository.h>
 #include <glib-object.h>
 
-#include "gjs/jsapi-wrapper.h"
-#include "js/GCHashTable.h"  // for GCHashMap
+#include <js/CallArgs.h>
+#include <js/Class.h>
+#include <js/GCHashTable.h>  // for GCHashMap
+#include <js/GCVector.h>     // for MutableWrappedPtrOperations
+#include <js/TracingAPI.h>
+#include <js/TypeDecls.h>
+#include <js/Value.h>
+#include <jsapi.h>  // for IdVector, JS_AtomizeAndPinJSString
+#include <mozilla/HashTable.h>
+#include <mozilla/Vector.h>
 
 #include "gi/arg.h"
 #include "gi/boxed.h"
@@ -134,7 +144,7 @@ BoxedPrototype::FieldMap* BoxedPrototype::create_field_map(
 
     auto* result = new BoxedPrototype::FieldMap();
     n_fields = g_struct_info_get_n_fields(struct_info);
-    if (!result->init(n_fields)) {
+    if (!result->reserve(n_fields)) {
         JS_ReportOutOfMemory(cx);
         return nullptr;
     }
@@ -600,30 +610,18 @@ bool BoxedInstance::set_nested_interface_object(JSContext* context,
 bool BoxedInstance::field_setter_impl(JSContext* context,
                                       GIFieldInfo* field_info,
                                       JS::HandleValue value) {
-    GITypeInfo *type_info;
     GArgument arg;
-    bool success = false;
-    bool need_release = false;
-
-    type_info = g_field_info_get_type (field_info);
+    GjsAutoTypeInfo type_info = g_field_info_get_type(field_info);
 
     if (!g_type_info_is_pointer (type_info) &&
         g_type_info_get_tag (type_info) == GI_TYPE_TAG_INTERFACE) {
+        GjsAutoBaseInfo interface_info = g_type_info_get_interface(type_info);
 
-        GIBaseInfo *interface_info = g_type_info_get_interface(type_info);
-
-        if (g_base_info_get_type (interface_info) == GI_INFO_TYPE_STRUCT ||
-            g_base_info_get_type (interface_info) == GI_INFO_TYPE_BOXED) {
-            success = set_nested_interface_object(context, field_info,
-                                                  interface_info, value);
-
-            g_base_info_unref ((GIBaseInfo *)interface_info);
-
-            goto out;
+        if (interface_info.type() == GI_INFO_TYPE_STRUCT ||
+            interface_info.type() == GI_INFO_TYPE_BOXED) {
+            return set_nested_interface_object(context, field_info,
+                                               interface_info, value);
         }
-
-        g_base_info_unref ((GIBaseInfo *)interface_info);
-
     }
 
     if (!gjs_value_to_g_argument(context, value,
@@ -632,28 +630,19 @@ bool BoxedInstance::field_setter_impl(JSContext* context,
                                  GJS_ARGUMENT_FIELD,
                                  GI_TRANSFER_NOTHING,
                                  true, &arg))
-        goto out;
-
-    need_release = true;
+        return false;
 
+    bool success = true;
     if (!g_field_info_set_field(field_info, m_ptr, &arg)) {
         gjs_throw(context, "Writing field %s.%s is not supported", name(),
                   g_base_info_get_name(field_info));
-        goto out;
+        success = false;
     }
 
-    success = true;
-
-out:
-    if (need_release) {
-        JS::AutoSaveExceptionState saved_exc(context);
-        if (!gjs_g_argument_release(context, GI_TRANSFER_NOTHING, type_info,
-                                    &arg))
-            gjs_log_exception(context);
-        saved_exc.restore();
-    }
-
-    g_base_info_unref ((GIBaseInfo *)type_info);
+    JS::AutoSaveExceptionState saved_exc(context);
+    if (!gjs_g_argument_release(context, GI_TRANSFER_NOTHING, type_info, &arg))
+        gjs_log_exception(context);
+    saved_exc.restore();
 
     return success;
 }
