@@ -24,15 +24,25 @@
 
 #include <config.h>
 
-#include <girepository.h>
+#include <glib-object.h>
+#include <glib.h>
 
-#include <unordered_map>
+#include <js/AllocPolicy.h>  // for SystemAllocPolicy
+#include <js/CallArgs.h>
+#include <js/Class.h>
+#include <js/GCHashTable.h>         // for WeakCache
+#include <js/PropertyDescriptor.h>  // for JSPROP_PERMANENT
+#include <js/PropertySpec.h>
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
+#include <jsapi.h>  // for JS_GetPropertyById, JS_AtomizeString
+#include <mozilla/HashTable.h>
 
 #include "gi/gtype.h"
+#include "gjs/atoms.h"
 #include "gjs/context-private.h"
 #include "gjs/jsapi-class.h"
-#include "gjs/jsapi-wrapper.h"
-#include "util/log.h"
+#include "gjs/jsapi-util.h"
 
 GJS_USE static JSObject* gjs_gtype_get_proto(JSContext* cx) G_GNUC_UNUSED;
 GJS_JSAPI_RETURN_CONVENTION
@@ -111,11 +121,13 @@ gjs_gtype_create_gtype_wrapper (JSContext *context,
     g_assert(((void) "Attempted to create wrapper object for invalid GType",
               gtype != 0));
 
-    JSAutoRequest ar(context);
-
     GjsContextPrivate* gjs = GjsContextPrivate::from_cx(context);
-    auto p = gjs->gtype_table().lookupForAdd(gtype);
-    if (p)
+    // We cannot use gtype_table().lookupForAdd() here, because in between the
+    // lookup and the add, GCs may take place and mutate the hash table. A GC
+    // may only remove an element, not add one, so it's still safe to do this
+    // without locking.
+    auto p = gjs->gtype_table().lookup(gtype);
+    if (p.found())
         return p->value();
 
     JS::RootedObject proto(context);
@@ -129,7 +141,7 @@ gjs_gtype_create_gtype_wrapper (JSContext *context,
 
     JS_SetPrivate(gtype_wrapper, GSIZE_TO_POINTER(gtype));
 
-    gjs->gtype_table().add(p, gtype, gtype_wrapper);
+    gjs->gtype_table().put(gtype, gtype_wrapper);
 
     return gtype_wrapper;
 }
@@ -171,7 +183,6 @@ static bool _gjs_gtype_get_actual_gtype(JSContext* context,
 bool gjs_gtype_get_actual_gtype(JSContext* context, JS::HandleObject object,
                                 GType* gtype_out) {
     g_assert(gtype_out && "Missing return location");
-    JSAutoRequest ar(context);
 
     /* 2 means: recurse at most three times (including this
        call).
