@@ -25,9 +25,11 @@
 #ifndef GI_GTYPE_H_
 #define GI_GTYPE_H_
 
+#include <config.h>
+
 #include <glib-object.h>
 
-#include "gjs/jsapi-wrapper.h"
+#include <js/TypeDecls.h>
 
 #include "gjs/macros.h"
 
