@@ -21,21 +21,16 @@
  * IN THE SOFTWARE.
  */
 
-#ifndef __GJS_NS_H__
-#define __GJS_NS_H__
+#ifndef GI_NS_H_
+#define GI_NS_H_
 
-#include <glib.h>
-#include <girepository.h>
-
-#include "gjs/jsapi-util.h"
 #include "gjs/macros.h"
 
-G_BEGIN_DECLS
+class JSObject;
+struct JSContext;
 
 GJS_JSAPI_RETURN_CONVENTION
 JSObject* gjs_create_ns(JSContext    *context,
                         const char   *ns_name);
 
-G_END_DECLS
-
-#endif  /* __GJS_NS_H__ */
+#endif  // GI_NS_H_
