@@ -21,9 +21,17 @@
  * IN THE SOFTWARE.
  */
 
+#include <config.h>
+
 #include <girepository.h>
 
-#include "gjs/jsapi-wrapper.h"
+#include <js/CallArgs.h>
+#include <js/Class.h>
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
+#include <js/Value.h>
+#include <js/Warnings.h>
+#include <jsapi.h>  // for HandleValueArray
 
 #include "gi/function.h"
 #include "gi/repo.h"
@@ -142,9 +150,10 @@ union_new(JSContext       *context,
 bool UnionInstance::constructor_impl(JSContext* context,
                                      JS::HandleObject object,
                                      const JS::CallArgs& args) {
-    if (args.length() > 0)
-        JS_ReportWarningASCII(context, "Arguments to constructor of %s ignored",
-                              name());
+    if (args.length() > 0 &&
+        !JS::WarnUTF8(context, "Arguments to constructor of %s ignored",
+                      name()))
+        return false;
 
     /* union_new happens to be implemented by calling
      * gjs_invoke_c_function(), which returns a JS::Value.
