@@ -345,7 +345,7 @@ import_module_init(JSContext       *context,
     }
 
     GjsAutoChar script = script_unowned;
-    g_assert(script != NULL);
+    g_assert(script);
 
     GjsAutoChar full_path = g_file_get_parse_name(file);
 
@@ -901,7 +901,10 @@ static const char* const* gjs_get_search_path(void) {
             g_free(dirs);
         }
 
-        g_ptr_array_add(path, g_strdup("resource:///org/gnome/gjs/modules/"));
+        g_ptr_array_add(path,
+                        g_strdup("resource:///org/gnome/gjs/modules/script/"));
+        g_ptr_array_add(path,
+                        g_strdup("resource:///org/gnome/gjs/modules/core/"));
 
         /* $XDG_DATA_DIRS /gjs-1.0 */
         system_data_dirs = g_get_system_data_dirs();
