@@ -110,3 +110,10 @@ class TapReporter {
 }
 
 window._jasmineEnv.addReporter(new TapReporter());
+
+// If we're running the tests in certain JS_GC_ZEAL modes, then some will time
+// out if the CI machine is under a certain load. In that case increase the
+// default timeout.
+const gcZeal = GLib.getenv('JS_GC_ZEAL');
+if (gcZeal && (gcZeal === '2' || gcZeal.startsWith('2,') || gcZeal === '4'))
+    jasmine.DEFAULT_TIMEOUT_INTERVAL *= 5;
