@@ -20,9 +20,15 @@
  * IN THE SOFTWARE.
  */
 
+#include <config.h>
+
 #include <cairo.h>
 
-#include "gjs/jsapi-wrapper.h"
+#include <js/CallArgs.h>
+#include <js/Class.h>
+#include <js/PropertySpec.h>
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
 
 #include "gjs/jsapi-class.h"
 #include "gjs/jsapi-util-args.h"
