@@ -20,11 +20,18 @@
  * IN THE SOFTWARE.
  */
 
+#include <config.h>
+
 #include <cairo-gobject.h>
 #include <cairo.h>
 #include <glib.h>
 
-#include "gjs/jsapi-wrapper.h"
+#include <js/CallArgs.h>
+#include <js/Class.h>
+#include <js/PropertySpec.h>
+#include <js/RootingAPI.h>
+#include <js/TypeDecls.h>
+#include <jsapi.h>  // for JS_GetPrivate, JS_GetClass, ...
 
 #include "gjs/jsapi-class.h"
 #include "gjs/jsapi-util.h"
@@ -32,9 +39,6 @@
 #include "modules/cairo-private.h"
 
 typedef struct {
-    void            *dummy;
-    JSContext       *context;
-    JSObject        *object;
     cairo_pattern_t *pattern;
 } GjsCairoPattern;
 
@@ -123,8 +127,6 @@ gjs_cairo_pattern_construct(JSContext       *context,
     g_assert(!priv_from_js(context, object));
     JS_SetPrivate(object, priv);
 
-    priv->context = context;
-    priv->object = object;
     priv->pattern = cairo_pattern_reference(pattern);
 }
 
