@@ -24,7 +24,9 @@
 #ifndef MODULES_CONSOLE_H_
 #define MODULES_CONSOLE_H_
 
-#include "gjs/jsapi-wrapper.h"
+#include <config.h>
+
+#include <js/TypeDecls.h>
 
 #include "gjs/macros.h"
 
