@@ -1,25 +1,37 @@
+#include <config.h>
+
 #include <stdint.h>
 #include <string.h>  // for strlen, strstr
 
 #include <glib.h>
 
-#include "gjs/jsapi-wrapper.h"
+#include <js/CallArgs.h>
+#include <js/CompilationAndEvaluation.h>
+#include <js/CompileOptions.h>
+#include <js/PropertySpec.h>
+#include <js/RootingAPI.h>
+#include <js/SourceText.h>
+#include <js/TypeDecls.h>
+#include <js/Utility.h>  // for UniqueChars
+#include <jsapi.h>       // for JS_DefineFunctions
 
 #include "gjs/jsapi-util-args.h"
 #include "gjs/jsapi-util.h"
 #include "test/gjs-test-common.h"
 #include "test/gjs-test-utils.h"
 
-#define assert_match(str, pattern)                                           \
-    G_STMT_START {                                                           \
-        const char *__s1 = (str), *__s2 = (pattern);                         \
-        if (!g_pattern_match_simple(__s2, __s1)) {                           \
-            g_assertion_message(G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, \
-                                "assertion failed (\"" #str                  \
-                                "\" matches \"" #pattern "\")");             \
-        }                                                                    \
-    }                                                                        \
-    G_STMT_END
+namespace mozilla {
+union Utf8Unit;
+}
+
+#define assert_match(str, pattern)                                            \
+    G_STMT_START {                                                            \
+        const char *__s1 = (str), *__s2 = (pattern);                          \
+        if (!g_pattern_match_simple(__s2, __s1)) {                            \
+            g_printerr("**\nExpected \"%s\" to match \"%s\"\n", __s1, __s2);  \
+            g_assert_not_reached();                                           \
+        }                                                                     \
+    } G_STMT_END
 
 typedef enum _test_enum {
     ZERO,
@@ -275,11 +287,16 @@ run_code(GjsUnitTestFixture *fx,
 {
     const char *script = (const char *) code;
 
+    JS::SourceText<mozilla::Utf8Unit> source;
+    bool ok = source.init(fx->cx, script, strlen(script),
+                          JS::SourceOwnership::Borrowed);
+    g_assert_true(ok);
+
     JS::CompileOptions options(fx->cx);
     options.setFileAndLine("unit test", 1);
 
     JS::RootedValue ignored(fx->cx);
-    bool ok = JS::Evaluate(fx->cx, options, script, strlen(script), &ignored);
+    ok = JS::Evaluate(fx->cx, options, source, &ignored);
 
     g_assert_null(gjs_test_get_exception_message(fx->cx));
     g_assert_true(ok);
@@ -291,11 +308,16 @@ run_code_expect_exception(GjsUnitTestFixture *fx,
 {
     const char *script = (const char *) code;
 
+    JS::SourceText<mozilla::Utf8Unit> source;
+    bool ok = source.init(fx->cx, script, strlen(script),
+                          JS::SourceOwnership::Borrowed);
+    g_assert_true(ok);
+
     JS::CompileOptions options(fx->cx);
     options.setFileAndLine("unit test", 1);
 
     JS::RootedValue ignored(fx->cx);
-    bool ok = JS::Evaluate(fx->cx, options, script, strlen(script), &ignored);
+    ok = JS::Evaluate(fx->cx, options, source, &ignored);
     g_assert_false(ok);
     GjsAutoChar message = gjs_test_get_exception_message(fx->cx);
     g_assert_nonnull(message);
